class CONFIG:
    __slots__ = (
        "blank",
        "x",
        "o",
        "up_left",
        "up",
        "up_right",
        "left",
        "mid",
        "right",
        "down_left",
        "down",
        "down_right",
    )
    blank = "\N{LARGE BLUE SQUARE}"
    x = "\N{REGIONAL INDICATOR SYMBOL LETTER X}"
    o = "\N{REGIONAL INDICATOR SYMBOL LETTER O}"
    up_left = "\N{NORTH WEST ARROW}"
    up = "\N{UPWARDS BLACK ARROW}"
    up_right = "\N{NORTH EAST ARROW}"
    left = "\N{LEFTWARDS BLACK ARROW}"
    mid = "\N{BLACK SQUARE FOR STOP}"
    right = "\N{BLACK RIGHTWARDS ARROW}"
    down_left = "\N{SOUTH WEST ARROW}"
    down = "\N{DOWNWARDS BLACK ARROW}"
    down_right = "\N{SOUTH EAST ARROW}"